@@ -44,9 +44,7 @@
 # include <calc/have_memmv.h>
 #endif
 
-#ifdef HAVE_MALLOC_H
-/* # include <malloc.h> */
-#else
+#ifndef HAVE_MALLOC_H
 #if defined(FORCE_STDC) || (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
    extern void *malloc();
    extern void *realloc();
