@@ -17,8 +17,8 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
  *
- * @(#) $Revision: 29.6 $
- * @(#) $Id: value.h,v 29.6 2001/05/29 00:16:53 chongo Exp $
+ * @(#) $Revision: 29.7 $
+ * @(#) $Id: value.h,v 29.7 2001/06/08 21:00:58 chongo Exp $
  * @(#) $Source: /usr/local/src/cmd/calc/RCS/value.h,v $
  *
  * Under source code control:	1993/07/30 19:42:47
@@ -32,7 +32,7 @@
 #define __VALUE_H__
 
 
-#if defined(SRC)	/* if we are building from the calc source tree */
+#if defined(CALC_SRC)	/* if we are building from the calc source tree */
 # include "calc/win32dll.h"
 # include "calc/cmath.h"
 # include "calc/config.h"
